'use strict'
Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' })
const naturalOrderby = require('natural-orderby')
let compare = (a, b, options) => {
  let orderCoefficient = options.order === 'asc' ? 1 : -1
  let sortingFunction
  let nodeValueGetter = options.nodeValueGetter ?? (node => node.name)
  if (options.type === 'alphabetical') {
    let formatString = getFormatStringFunction(
      options.ignoreCase,
      options.specialCharacters,
    )
    sortingFunction = (aNode, bNode) =>
      formatString(nodeValueGetter(aNode)).localeCompare(
        formatString(nodeValueGetter(bNode)),
        options.locales,
      )
  } else if (options.type === 'natural') {
    let naturalCompare = naturalOrderby.compare({
      locale: options.locales.toString(),
      order: options.order,
    })
    let formatString = getFormatStringFunction(
      options.ignoreCase,
      options.specialCharacters,
    )
    sortingFunction = (aNode, bNode) =>
      naturalCompare(
        formatString(nodeValueGetter(aNode)),
        formatString(nodeValueGetter(bNode)),
      )
  } else {
    sortingFunction = (aNode, bNode) => {
      let aSize = aNode.size
      let bSize = bNode.size
      let { maxLineLength } = options
      if (maxLineLength) {
        let isTooLong = (size, node) =>
          size > maxLineLength && node.hasMultipleImportDeclarations
        if (isTooLong(aSize, aNode)) {
          aSize = nodeValueGetter(aNode).length + 10
        }
        if (isTooLong(bSize, bNode)) {
          bSize = nodeValueGetter(bNode).length + 10
        }
      }
      return aSize - bSize
    }
  }
  return orderCoefficient * sortingFunction(a, b)
}
let getFormatStringFunction = (ignoreCase, specialCharacters) => value => {
  let valueToCompare = value
  if (ignoreCase) {
    valueToCompare = valueToCompare.toLowerCase()
  }
  switch (specialCharacters) {
    case 'remove':
      valueToCompare = valueToCompare.replaceAll(
        /[^a-z\u{C0}-\u{24F}\u{1E00}-\u{1EFF}]+/giu,
        '',
      )
      break
    case 'trim':
      valueToCompare = valueToCompare.replaceAll(
        /^[^a-z\u{C0}-\u{24F}\u{1E00}-\u{1EFF}]+/giu,
        '',
      )
      break
  }
  return valueToCompare.replaceAll(/\s/gu, '')
}
exports.compare = compare
