'use strict'
Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' })
const getLinesBetween = require('./get-lines-between.js')
const getGroupNumber = require('./get-group-number.js')
const getNodeRange = require('./get-node-range.js')
let makeNewlinesFixes = ({
  sortedNodes,
  sourceCode,
  options,
  fixer,
  nodes,
}) => {
  let fixes = []
  for (let max = sortedNodes.length, i = 0; i < max; i++) {
    let sortingNode = sortedNodes.at(i)
    let nextSortingNode = sortedNodes.at(i + 1)
    if (options.newlinesBetween === 'ignore' || !nextSortingNode) {
      continue
    }
    let nodeGroupNumber = getGroupNumber.getGroupNumber(
      options.groups,
      sortingNode,
    )
    let nextNodeGroupNumber = getGroupNumber.getGroupNumber(
      options.groups,
      nextSortingNode,
    )
    let currentNodeRange = getNodeRange.getNodeRange(
      nodes.at(i).node,
      sourceCode,
    )
    let nextNodeRangeStart = getNodeRange
      .getNodeRange(nodes.at(i + 1).node, sourceCode)
      .at(0)
    let rangeToReplace = [currentNodeRange.at(1), nextNodeRangeStart]
    let textBetweenNodes = sourceCode.text.slice(
      currentNodeRange.at(1),
      nextNodeRangeStart,
    )
    let linesBetweenMembers = getLinesBetween.getLinesBetween(
      sourceCode,
      nodes.at(i),
      nodes.at(i + 1),
    )
    let rangeReplacement
    if (
      (options.newlinesBetween === 'always' &&
        nodeGroupNumber === nextNodeGroupNumber &&
        linesBetweenMembers !== 0) ||
      (options.newlinesBetween === 'never' && linesBetweenMembers > 0)
    ) {
      rangeReplacement = getStringWithoutInvalidNewlines(textBetweenNodes)
    }
    if (
      options.newlinesBetween === 'always' &&
      nodeGroupNumber !== nextNodeGroupNumber &&
      linesBetweenMembers !== 1
    ) {
      rangeReplacement = addNewlineBeforeFirstNewline(
        linesBetweenMembers > 1
          ? getStringWithoutInvalidNewlines(textBetweenNodes)
          : textBetweenNodes,
      )
      let isOnSameLine =
        linesBetweenMembers === 0 &&
        nodes.at(i).node.loc.end.line === nodes.at(i + 1).node.loc.start.line
      if (isOnSameLine) {
        rangeReplacement = addNewlineBeforeFirstNewline(rangeReplacement)
      }
    }
    if (rangeReplacement) {
      fixes.push(fixer.replaceTextRange(rangeToReplace, rangeReplacement))
    }
  }
  return fixes
}
let getStringWithoutInvalidNewlines = value =>
  value.replaceAll(/\n\s*\n/gu, '\n').replaceAll(/\n+/gu, '\n')
let addNewlineBeforeFirstNewline = value => {
  let firstNewlineIndex = value.indexOf('\n')
  if (firstNewlineIndex === -1) {
    return `${value}
`
  }
  return `${value.slice(0, firstNewlineIndex)}
${value.slice(firstNewlineIndex)}`
}
exports.makeNewlinesFixes = makeNewlinesFixes
